.. _ablot:

**************************
Median Image Blotting Step
**************************

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. automodule:: drizzlepac.ablot
   :members:
   :undoc-members:
